/*==============================================================================
This file replicates Figure 3 of the JMCB paper
"Countercyclical Capital Buffers: A Cautionary Tale" by

Christoffer Koch (International Monetary Fund)
Gary Richardon (UC Irvine)
Patrick Van Horn (Scripps College)

==============================================================================*/

set varabbrev off
version 15.1
clear all 
capture noisily cd ${MasterDirectory}

// generate a date set with start and end dates that are then interpolated
// based on the STATA daily index.

set obs 2

gen t_h_bc_1 = mdy(10,01,1927)
replace t_h_bc_1 = mdy(09,30,1929) in 2
gen t_h_bc_2 = mdy(07,01,1922)
replace t_h_bc_2 = mdy(09,30,1929) in 2
gen t_h_bc_3 = mdy(07,01,1921)
replace t_h_bc_3 = mdy(06,30,1930) in 2
gen t_h_bc_4 = mdy(07,01,1921)
replace t_h_bc_4 = mdy(09,30,1929) in 2
gen t_h_bc_5 = mdy(07,01,1923)
replace t_h_bc_5 = mdy(12,31,1929) in 2
gen t_h_bc_6 = mdy(07,01,1924)
replace t_h_bc_6 = mdy(09,30,1929) in 2

gen t_m_bc_1 = mdy(10,01,2001)
replace t_m_bc_1 = mdy(12,31,2007) in 2
gen t_m_bc_2 = mdy(01,01,2004)
replace t_m_bc_2 = mdy(09,30,2007) in 2
gen t_m_bc_3 = mdy(01,01,2003)
replace t_m_bc_3 = mdy(06,30,2008) in 2
gen t_m_bc_4 = mdy(10,01,2002)
replace t_m_bc_4 = mdy(12,31,2007) in 2
gen t_m_bc_5 = mdy(07,01,2003)
replace t_m_bc_5 = mdy(12,31,2007) in 2
gen t_m_bc_6 = mdy(07,01,2003)
replace t_m_bc_6 = mdy(03,31,2008) in 2
gen index = _n - 1

//ssc install savesome

// interpolating the unit interval from zero to unity 
// based on d_date interpolation
// "h" stands for historic period (1920-1930)
// "m" stands for the modern period (2000-2010)

forvalues ii = 1/6 {

	preserve
		keep index t_h_bc_`ii'
		tsset t_h_bc_`ii', d
		tsfill
		ipolate index t_h_bc_`ii', gen(h_bc_`ii')
		rename t_h_bc_`ii' d_date 
		savesome d_date h_bc_`ii' using .\data\aux_h_bc_`ii'.dta, replace
	restore

	preserve
		keep index t_m_bc_`ii'
		tsset t_m_bc_`ii', d
		tsfill
		ipolate index t_m_bc_`ii', gen(m_bc_`ii')
		rename t_m_bc_`ii' d_date 
		savesome d_date m_bc_`ii' using .\data\aux_m_bc_`ii'.dta, replace
	restore

}

// restarting with a blank continuous data set
clear
set obs 2
gen d_date = mdy(7,1,1921)
replace d_date = mdy(3,31,2008) in 2
tsset d_date, d
tsfill

// merging the generated unit intervals onto that data set
merge 1:1 d_date using .\data\aux_h_bc_1.dta, nogenerate
merge 1:1 d_date using .\data\aux_h_bc_2.dta, nogenerate
merge 1:1 d_date using .\data\aux_h_bc_3.dta, nogenerate
merge 1:1 d_date using .\data\aux_h_bc_4.dta, nogenerate
merge 1:1 d_date using .\data\aux_h_bc_5.dta, nogenerate
merge 1:1 d_date using .\data\aux_h_bc_6.dta, nogenerate

merge 1:1 d_date using .\data\aux_m_bc_1.dta, nogenerate
merge 1:1 d_date using .\data\aux_m_bc_2.dta, nogenerate
merge 1:1 d_date using .\data\aux_m_bc_3.dta, nogenerate
merge 1:1 d_date using .\data\aux_m_bc_4.dta, nogenerate
merge 1:1 d_date using .\data\aux_m_bc_5.dta, nogenerate
merge 1:1 d_date using .\data\aux_m_bc_6.dta, nogenerate

// erasing the redundant auxiliary files
erase .\data\aux_h_bc_1.dta
erase .\data\aux_h_bc_2.dta
erase .\data\aux_h_bc_3.dta
erase .\data\aux_h_bc_4.dta
erase .\data\aux_h_bc_5.dta
erase .\data\aux_h_bc_6.dta
erase .\data\aux_m_bc_1.dta
erase .\data\aux_m_bc_2.dta
erase .\data\aux_m_bc_3.dta
erase .\data\aux_m_bc_4.dta
erase .\data\aux_m_bc_5.dta
erase .\data\aux_m_bc_6.dta
 

// saving the unit interval business cycle file
tsset d_date, d
saveold ts_business_cycles_on_unit_interval.dta, replace version(11)

set autotabgraphs on 

tsline h_bc_1 h_bc_2 h_bc_3 h_bc_4 h_bc_5 h_bc_6  ///
if d_date <mdy(1,1,1931), lw(thick..) ///
ylab(0(.1)1, nogrid angle(horizontal) format(%4.1fc)) ///
ttitle("Calendar Time", s(large)) title("Historical", s(large) c(black) span) ///
ytitle("Business Cycle Time", s(large)) ///
graphregion(c(white) margin(0 5 0 0)) plotregion(c(white) margin(0 0 0 0)) ysize(3) xsize(4.8) ///
tlab(1jan1920 1jan1921 1jan1922 1jan1923 1jan1924 1jan1925 1jan1926 1jan1927 1jan1928 1jan1929 1jan1930 1jan1931, format(%tdCY)) ///
tmtick(1jan1920 1apr1920 1jul1920 1oct1920 1jan1921 1apr1921 1jul1921 1oct1921 1jan1922 1apr1922 1jul1922 1oct1922 1jan1923 1apr1923 1jul1923 1oct1923 1jan1924 1apr1924 1jul1924 1oct1924 1jan1925 1apr1925 1jul1925 1oct1925 1jan1926 1apr1926 1jul1926 1oct1926 1jan1927 1apr1927 1jul1927 1oct1927 1jan1928 1apr1928 1jul1928 1oct1928 1jan1929 1apr1929 1jul1929 1oct1929 1jan1930 1apr1930 1jul1930 1oct1930 1jan1931) ///
	legend(order(1 "NBER"  ///
				 2 "Short-term interest rate" ///
				 3 "Consumption" ///
				 4 "DJIA" ///
				 5 "Volume of Payments" ///
				 6 "Total Payrolls" ///
				 ) ///
	  size(medium) cols(1) ring(0) pos(11) region(ls(none) sty(none))) name(hist_co, replace) 

// graph export .\output\KRVH2022JMCB_figure3a_co.png, as(png) replace
// graph export .\output\KRVH2022JMCB_figure3a_co.pdf, as(pdf) replace

tsline h_bc_1 h_bc_2 h_bc_3 h_bc_4 h_bc_5 h_bc_6  ///
if d_date <mdy(1,1,1931), lc(black..) lw(thick..) lp(solid dash dot longdash dash_dot dash_3dot) ///
ylab(0(.1)1, nogrid angle(horizontal) format(%4.1fc)) ///
ttitle("") title("Historical Business Cycles Unit Intervals", s(medium) c(black)) ///
graphregion(c(white) margin(0 5 0 0)) plotregion(c(white) margin(0 0 0 0)) ysize(3) xsize(4.8) ///
tlab(1jan1920 1jan1921 1jan1922 1jan1923 1jan1924 1jan1925 1jan1926 1jan1927 1jan1928 1jan1929 1jan1930 1jan1931, format(%tdCY)) ///
tmtick(1jan1920 1apr1920 1jul1920 1oct1920 1jan1921 1apr1921 1jul1921 1oct1921 1jan1922 1apr1922 1jul1922 1oct1922 1jan1923 1apr1923 1jul1923 1oct1923 1jan1924 1apr1924 1jul1924 1oct1924 1jan1925 1apr1925 1jul1925 1oct1925 1jan1926 1apr1926 1jul1926 1oct1926 1jan1927 1apr1927 1jul1927 1oct1927 1jan1928 1apr1928 1jul1928 1oct1928 1jan1929 1apr1929 1jul1929 1oct1929 1jan1930 1apr1930 1jul1930 1oct1930 1jan1931) ///
	legend(order(1 "NBER"  ///
				 2 "Short-term interest rate" ///
				 3 "Consumption" ///
				 4 "DJIA" ///
				 5 "Volume of Payments" ///
				 6 "Total Payrolls" ///
				 ) ///
	  size(medium) cols(1) ring(0) pos(11) region(ls(none) sty(none))) name(hist_nw, replace)


// graph export .\output\KRVH2022JMCB_figure3a_bw.png, as(png) replace
// graph export .\output\KRVH2022JMCB_figure3a_bw.pdf, as(pdf) replace


tsline m_bc_1 m_bc_2 m_bc_3 m_bc_4 m_bc_5 m_bc_6 ///
if (d_date < mdy(1,1,2009) & d_date > mdy(12,1,1999)), lw(thick..) ///
ylab(0(.1)1, nogrid angle(horizontal) format(%4.1fc)) ///
ttitle("Calendar Time", s(large)) title("Modern", s(large) c(black) span) ///
ytitle("Business Cycle Time", s(large)) ///
graphregion(c(white) margin(0 5 0 0)) plotregion(c(white) margin(0 0 0 0)) ysize(3) xsize(4.8) ///
tlab(1jan2000 1jan2001 1jan2002 1jan2003 1jan2004 1jan2005 1jan2006 1jan2007 1jan2008 1jan2009, format(%tdCY)) ///
tmtick(1jan2000 1apr2000 1jul2000 1oct2000 1jan2001 1apr2001 1jul2001 1oct2001 1jan2002 1apr2002 1jul2002 1oct2002 1jan2003 1apr2003 1jul2003 1oct2003 1jan2004 1apr2004 1jul2004 1oct2004 1jan2005 1apr2005 1jul2005 1oct2005 1jan2006 1apr2006 1jul2006 1oct2006 1jan2007 1apr2007 1jul2007 1oct2007 1jan2008 1apr2008 1jul2008 1oct2008 1jan2009) ///
	legend(order(1 "NBER"  ///
				 2 "Short-term interest rate" ///
				 3 "Consumption" ///
				 4 "DJIA" ///
				 5 "Volume of Payments" ///
				 6 "Total Payrolls" ///
				 ) ///
	  size(medium) cols(1) ring(0) pos(11) region(ls(none) sty(none))) name(modn_co, replace)

// graph export .\output\KRVH2022JMCB_figure3b_co.png, as(png) replace
// graph export .\output\KRVH2022JMCB_figure3b_co.pdf, as(pdf) replace

tsline m_bc_1 m_bc_2 m_bc_3 m_bc_4 m_bc_5 m_bc_6 ///
if (d_date < mdy(1,1,2009) & d_date > mdy(12,1,1999)), lc(black..) lw(thick..) lp(solid dash dot longdash dash_dot dash_3dot) ///
ylab(0(.1)1, nogrid angle(horizontal) format(%4.1fc)) ///
ttitle("Calendar Time", s(large)) title("Modern", s(large) c(black) span) ///
ytitle("Business Cycle Time", s(large)) ///
graphregion(c(white) margin(0 5 0 0)) plotregion(c(white) margin(0 0 0 0)) ysize(3) xsize(4.8) ///
tlab(1jan2000 1jan2001 1jan2002 1jan2003 1jan2004 1jan2005 1jan2006 1jan2007 1jan2008 1jan2009, format(%tdCY)) ///
tmtick(1jan2000 1apr2000 1jul2000 1oct2000 1jan2001 1apr2001 1jul2001 1oct2001 1jan2002 1apr2002 1jul2002 1oct2002 1jan2003 1apr2003 1jul2003 1oct2003 1jan2004 1apr2004 1jul2004 1oct2004 1jan2005 1apr2005 1jul2005 1oct2005 1jan2006 1apr2006 1jul2006 1oct2006 1jan2007 1apr2007 1jul2007 1oct2007 1jan2008 1apr2008 1jul2008 1oct2008 1jan2009) ///
	legend(order(1 "NBER"  ///
				 2 "Short-term interest rate" ///
				 3 "Consumption" ///
				 4 "DJIA" ///
				 5 "Volume of Payments" ///
				 6 "Total Payrolls" ///
				 ) ///
	  size(medium) cols(1) ring(0) pos(11) region(ls(none) sty(none))) name(modn_bw, replace)

// graph export .\output\KRVH2022JMCB_figure3b_bw.png, as(png) replace
// graph export .\output\KRVH2022JMCB_figure3b_bw.pdf, as(pdf) replace

// END OF FILE //
