capture noisily log close _all
capture noisily log using ./output/log_3_modern_regressions.log, text name(modern) replace
/*
filename: tab_3_modern_regressions.do

This file estimates the business cycle regressions for the modern bank
level data.

Programs in this file:

- NewModernReportingTemplate
- ModernRankBasedRegressions
- ModernSizeCutoffRegressions

Programs from outside this file:
- results2xls (from tab_1_baseline_regression.do)
- results2dta (from tab_1_baseline_regression.do)



*/

clear

use xt_mod_qq.dta, clear

merge m:1 d_date using ts_business_cycles_on_unit_interval.dta
tab _merge
keep if _merge ==3
drop _merge
drop h_bc_*
drop if bank_id == .

// generating six results summaries for the subsequent results visualization  
gen dtaID = .
gen dtaBusCy = .
gen dtaModel = ""
gen dtaDepVar = ""
gen dtaSizeCutoff = ""
gen dtaEstimate = . 
gen dtaStdErr = .




gen c_asset1 = 100*(loans/assets)
gen c_asset2 = 100*(securities/assets)
gen c_asset3 = 100*(cash/assets)

// dropping observations outside the six business cycle definitions
drop if (m_bc_1 == . & m_bc_2 == . & m_bc_3 == . & m_bc_4 == . & m_bc_5 == . & m_bc_6 == .)


// dependent variables in percent rather than fraction

replace tier1_leverage_ratio = 100*tier1_leverage_ratio
replace total_risk_based_capital_ratio = 100*total_risk_based_capital_ratio 
replace tier1_risk_based_capital_ratio = 100*tier1_risk_based_capital_ratio

// eliminating de-novo (younger than 5 years) banks

tostring dt_open, g(dt_open_str) 
gen established = qofd(date(dt_open_str,"YMD"))
format established %tqCY_!Qq
gen age = (q_date-established)/4
order dt_open establishe* q_date age, first
gen IndDeNovo = cond(age<=5,1,0)
tab q_date IndDeNovo

xtset bank_id q_date, q

// more on the lincom constraints: https://www.stata.com/statalist/archive/2012-11/msg01179.html

capture noisily program drop NewModernReportingTemplate
program define NewModernReportingTemplate

	/*
	As there might be re-sorts during the intermittent data management
	each set of regressions is preceded by a new template that is
	then exported to Excel. This program creates the modern regressions
	table template.
	*/

	capture noisily drop Results*
	
	gen ResultsColumnT = "" in 1
	
	replace ResultsColumnT = "Tier 1" in 2
	replace ResultsColumnT = "Leverage" in 3
	replace ResultsColumnT = "Ratio" in 4
	
	replace ResultsColumnT = "Tier 1" in 8
	replace ResultsColumnT = "Risk-Based" in 9
	replace ResultsColumnT = "Capital" in 10
	
	replace ResultsColumnT = "Total " in 14
	replace ResultsColumnT = "Risk-Based" in 15
	replace ResultsColumnT = "Capital" in 16
	
	replace ResultsColumnT = "Equity" in 20
	replace ResultsColumnT = "Capital" in 21
	replace ResultsColumnT = "Ratio" in 22

	gen ResultsColumn0 = "Specification" in 1
	replace ResultsColumn0 = "Baseline" in 2
	replace ResultsColumn0 = "S.E." in 3
	replace ResultsColumn0 = "Time-Fixed Effects" in 5
	replace ResultsColumn0 = "S.E." in 6

	replace ResultsColumn0 = "Baseline" in 8
	replace ResultsColumn0 = "S.E." in 9
	replace ResultsColumn0 = "Time-Fixed Effects" in 11
	replace ResultsColumn0 = "S.E." in 12

	replace ResultsColumn0 = "Baseline" in 14
	replace ResultsColumn0 = "S.E." in 15
	replace ResultsColumn0 = "Time-Fixed Effects" in 17
	replace ResultsColumn0 = "S.E." in 18

	replace ResultsColumn0 = "Baseline" in 20
	replace ResultsColumn0 = "S.E." in 21
	replace ResultsColumn0 = "Time-Fixed Effects" in 23
	replace ResultsColumn0 = "S.E." in 24

	gen ResultsColumn1 = "Business Cycle Definition 1" in 1
	gen ResultsColumn2 = "Business Cycle Definition 2" in 1
	gen ResultsColumn3 = "Business Cycle Definition 3" in 1
	gen ResultsColumn4 = "Business Cycle Definition 4" in 1
	gen ResultsColumn5 = "Business Cycle Definition 5" in 1
	gen ResultsColumn6 = "Business Cycle Definition 6" in 1

	label var ResultsColumn1 "NBER"
	label var ResultsColumn2 "Short-term interest rate"
	label var ResultsColumn3 "Consumption"
	label var ResultsColumn4 "DJIA"
	label var ResultsColumn5 "Volume of Payments"
	label var ResultsColumn6 "Total Payroll"

	order ResultsColumnT Results*, first
	
end

gsort q_date -assets
by q_date: gen quarter_size_rank = _n
by q_date: gen top_size = cond(_n<=20,1,0)
gsort q_date -gross_interconnectedness
by q_date: gen top_cent = cond(_n<=20,1,0)

gsort q_date -assets

// clearing the reporting template and replacing it with a blank one
// to prevent "carry over" from stale (previous) estimates
NewModernReportingTemplate

capture noisily program drop ModernRankBasedRegressions
program define ModernRankBasedRegressions

	/*
	This file sorts the modern banks by assets in each quarter and compares the 
	k-highest size-ranked banks to the remaining banks.
	
	inputs:
	`1' ... largest or most interconnected banks (number of them)
	`2' ... top size versus top interconnected (by gross interconnectedness)
	`3' ... additional subset conditions (regulatory highholder BHCs etc.)
	*/
	
	if "`2'" == "size" {
	
		
		if "`3'" == "" {
		
			gsort q_date -assets
			//by q_date: gen quarter_rank = _n
			by q_date: replace top_size = cond(_n<=`1',1,0)
		
		}
	
		if "`3'" == " & bhc == 1" {

		gsort q_date -bhc -assets
		//by q_date: gen quarter_rank = _n
		by q_date: replace top_size = cond(_n<=`1',1,0)	
	
		}
	
		if "`3'" == " & bhc == 0" {
	
		gsort q_date bhc -assets
		//by q_date: gen quarter_rank = _n
		by q_date: replace top_size = cond(_n<=`1',1,0)	
		
		}
	
		if "`3'" == " & state_cd == 36" {
			
			gen aux1 = cond(state_cd==36,1,0)
			gsort q_date -aux1 -assets
			//by q_date: gen quarter_rank = _n
			by q_date: replace top_size = cond(_n<=`1',1,0)	
			drop aux1
		}
	
		if "`3'" == "& (state_cd == 36 | state_cd == 37 | state_cd == 10)" {
			
			gen aux1 = cond((state_cd == 36 | state_cd == 37 | state_cd == 10),1,0)
			gsort q_date -aux2 -assets
			//by q_date: gen quarter_rank = _n
			by q_date: replace top_size = cond(_n<=`1',1,0)	
			drop aux2
		}		
	}
	
	else if "`2'" == "cent" {

		if "`3'" == "" {
		
			gsort q_date -gross_interconnectedness
			//by q_date: gen quarter_rank = _n
			by q_date: replace top_cent = cond(_n<=`1',1,0)
		
		}
		
		if "`3'" == " & bhc == 1" {

			gsort q_date -bhc -gross_interconnectedness
			//by q_date: gen quarter_rank = _n
			by q_date: replace top_cent = cond(_n<=`1',1,0)	
		
		}
	
		if "`3'" == " & bhc == 0" {
	
			gsort q_date bhc -gross_interconnectedness
			//by q_date: gen quarter_rank = _n
			by q_date: replace top_cent = cond(_n<=`1',1,0)	

		}
		
		
		if "`3'" == " & state_cd == 36" {
			
			gen aux1 = cond(state_cd==36,1,0)
			gsort q_date -aux1 -gross_interconnectedness
			//by q_date: gen quarter_rank = _n
			by q_date: replace top_cent = cond(_n<=`1',1,0)	
			drop aux1
		}
	
		if "`3'" == "& (state_cd == 36 | state_cd == 37 | state_cd == 10)" {
			
			gen aux1 = cond((state_cd == 36 | state_cd == 37 | state_cd == 10),1,0)
			gsort q_date -aux2 -gross_interconnectedness
			//by q_date: gen quarter_rank = _n
			by q_date: replace top_cent = cond(_n<=`1',1,0)	
			drop aux2
		}		
	}
	
	// clearing the reporting template and replacing it with a blank one
	// to prevent "carry over" from stale (previous) estimates
	
	NewModernReportingTemplate
	
	forvalues bc = 1/6 {

		global SubSet "tier1_leverage <50 & tier1_leverage>4 & IndDeNovo == 0 `3'"
		global controls "c_asset1 c_asset2 c_asset3"

		display "Business Cycle: `bc'"	
		display "Number of largest banks: `1'"
		display "Largest by: `2'"
		// no time-fixed effects
		xtreg tier1_leverage i.top_`2'##c.m_bc_`bc' ${controls} if ${SubSet}, fe vce(cluster bank_id)
		display "`e(cmdline)'"
		lincom 1.top_`2'#c.m_bc_`bc' - c.m_bc_`bc', cformat(%9.2fc) 
		results2xls `bc' 2
		di "`bc' `e(cmdline)' `e(depvar)' `r(estimate)' `r(se)' `1'"
		results2dta "`bc'" "`e(cmdline)'" "`e(depvar)'" "`r(estimate)'" "`r(se)'" "MOD `2' TOP `1'`3'"

		display "Business Cycle: `bc'"	
		display "Number of largest banks: `1'"
		display "Largest by: `2'"
		// time-fixed effects	
		xtreg tier1_leverage i.top_`2'##c.m_bc_`bc' i.q_date ${controls} if ${SubSet}, fe vce(cluster bank_id)
		display "`e(cmdline)'"
		lincom 1.top_`2'#c.m_bc_`bc' - c.m_bc_`bc', cformat(%9.2fc) 
		lincom 1.top_`2'#c.m_bc_`bc', cformat(%9.2fc) 
		results2xls `bc' 5
		di "`bc' `e(cmdline)' `e(depvar)' `r(estimate)' `r(se)' `1'"
		results2dta "`bc'" "`e(cmdline)'" "`e(depvar)'" "`r(estimate)'" "`r(se)'" "MOD `2' TOP `1'`3' - TFE"

		global SubSet "tier1_risk_based <50 & tier1_risk_based>4 & IndDeNovo == 0 `3'"

		display "Business Cycle: `bc'"	
		display "Number of largest banks: `1'"
		display "Largest by: `2'"
		// no time-fixed effects
		xtreg tier1_risk_based i.top_`2'##c.m_bc_`bc' ${controls} if ${SubSet}, fe vce(cluster bank_id)
		display "`e(cmdline)'"
		lincom 1.top_`2'#c.m_bc_`bc' - c.m_bc_`bc', cformat(%9.2fc) 
		results2xls `bc' 8
		di "`bc' `e(cmdline)' `e(depvar)' `r(estimate)' `r(se)' `1'"
		results2dta "`bc'" "`e(cmdline)'" "`e(depvar)'" "`r(estimate)'" "`r(se)'" "MOD `2' TOP `1'`3'"

		display "Business Cycle: `bc'"	
		display "Number of largest banks: `1'"
		display "Largest by: `2'"
		// time-fixed effects
		xtreg tier1_risk_based i.top_`2'##c.m_bc_`bc' i.q_date ${controls} if ${SubSet}, fe vce(cluster bank_id)
		lincom 1.top_`2'#c.m_bc_`bc' - c.m_bc_`bc', cformat(%9.2fc) 
		lincom 1.top_`2'#c.m_bc_`bc', cformat(%9.2fc) 
		results2xls `bc' 11
		di "`bc' `e(cmdline)' `e(depvar)' `r(estimate)' `r(se)' `1'"
		results2dta "`bc'" "`e(cmdline)'" "`e(depvar)'" "`r(estimate)'" "`r(se)'" "MOD `2' TOP `1'`3' - TFE"

		global SubSet "total_risk_based <50 & total_risk_based>4 & IndDeNovo == 0"

		display "Business Cycle: `bc'"	
		display "Number of largest banks: `1'"
		display "Largest by: `2'"
		// no time-fixed effects	
		xtreg total_risk_based i.top_`2'##c.m_bc_`bc' ${controls} if ${SubSet}, fe vce(cluster bank_id)
		lincom 1.top_`2'#c.m_bc_`bc' - c.m_bc_`bc', cformat(%9.2fc) 
		results2xls `bc' 14
		di "`bc' `e(cmdline)' `e(depvar)' `r(estimate)' `r(se)' `1'"
		results2dta "`bc'" "`e(cmdline)'" "`e(depvar)'" "`r(estimate)'" "`r(se)'" "MOD `2' TOP `1'`3'"

		display "Business Cycle: `bc'"	
		display "Number of largest banks: `1'"
		display "Largest by: `2'"
		// time-fixed effects
		xtreg total_risk_based i.top_`2'##c.m_bc_`bc' i.q_date ${controls} if ${SubSet}, fe vce(cluster bank_id)		
		display "`e(cmdline)'"
		lincom 1.top_`2'#c.m_bc_`bc' - c.m_bc_`bc', cformat(%9.2fc) 
		lincom 1.top_`2'#c.m_bc_`bc', cformat(%9.2fc) 
		results2xls `bc' 17
		di "`bc' `e(cmdline)' `e(depvar)' `r(estimate)' `r(se)' `1'"
		results2dta "`bc'" "`e(cmdline)'" "`e(depvar)'" "`r(estimate)'" "`r(se)'" "MOD `2' TOP `1'`3' - TFE"

		global SubSet "eqt < 50 & eqt > 4 & IndDeNovo == 0  `3'"

		display "Business Cycle: `bc'"	
		display "Number of largest banks: `1'"
		display "Largest by: `2'"
		// no time-fixed effects
		xtreg eqt i.top_`2'##c.m_bc_`bc' ${controls} if ${SubSet}, fe vce(cluster bank_id)
		display "`e(cmdline)'"
		lincom 1.top_`2'#c.m_bc_`bc' - c.m_bc_`bc', cformat(%9.2fc) 
		results2xls `bc' 20
		di "`bc' `e(cmdline)' `e(depvar)' `r(estimate)' `r(se)' `1'"
		results2dta "`bc'" "`e(cmdline)'" "`e(depvar)'" "`r(estimate)'" "`r(se)'" "MOD `2' TOP `1'`3'"
		
		display "Business Cycle: `bc'"	
		display "Number of largest banks: `1'"
		display "Largest by: `2'"
		// time-fixed effects
		xtreg eqt i.top_`2'##c.m_bc_`bc' i.q_date ${controls} if ${SubSet}, fe vce(cluster bank_id)
		display "`e(cmdline)'"
		lincom 1.top_`2'#c.m_bc_`bc' - c.m_bc_`bc', cformat(%9.2fc) 
		lincom 1.top_`2'#c.m_bc_`bc', cformat(%9.2fc) 
		results2xls `bc' 23
		di "`bc' `e(cmdline)' `e(depvar)' `r(estimate)' `r(se)' `1'"
		results2dta "`bc'" "`e(cmdline)'" "`e(depvar)'" "`r(estimate)'" "`r(se)'" "MOD `2' TOP `1'`3' - TFE"

		
	}

	export excel ResultsColumnT ResultsColumn0 ResultsColumn1 ResultsColumn2 ResultsColumn3 ResultsColumn4 ResultsColumn5 ResultsColumn6 ///
	in 1/25 using "./output/tab_baseline.xlsx", sheet("mod `2' top `1'`3'") sheetreplace cell(b2) firstrow(varlabels) keepcellfmt
	
end


// TOP 10 SIZED BANKS EACH QUARTER


ModernRankBasedRegressions 5 "size"
ModernRankBasedRegressions 10 "size"
ModernRankBasedRegressions 20 "size"
ModernRankBasedRegressions 30 "size"
ModernRankBasedRegressions 40 "size"
ModernRankBasedRegressions 50 "size"
ModernRankBasedRegressions 100 "size"
ModernRankBasedRegressions 1000 "size"

ModernRankBasedRegressions 5 "cent"
ModernRankBasedRegressions 10 "cent"
ModernRankBasedRegressions 20 "cent"
ModernRankBasedRegressions 30 "cent"
ModernRankBasedRegressions 40 "cent"
ModernRankBasedRegressions 50 "cent"
ModernRankBasedRegressions 100 "cent"
ModernRankBasedRegressions 1000 "cent"

ModernRankBasedRegressions 5 "size" ""
ModernRankBasedRegressions 10 "size" ""
ModernRankBasedRegressions 20 "size" ""
ModernRankBasedRegressions 30 "size" ""
ModernRankBasedRegressions 40 "size" ""
ModernRankBasedRegressions 50 "size" ""
ModernRankBasedRegressions 100 "size" ""
ModernRankBasedRegressions 1000 "size" ""

ModernRankBasedRegressions 5 "cent" ""
ModernRankBasedRegressions 10 "cent" ""
ModernRankBasedRegressions 20 "cent" ""
ModernRankBasedRegressions 30 "cent" ""
ModernRankBasedRegressions 40 "cent" ""
ModernRankBasedRegressions 50 "cent" ""
ModernRankBasedRegressions 100 "cent" ""
ModernRankBasedRegressions 1000 "cent" ""

/*
Generate and use Bank Holding Company indicator, i.e.
whether the commercial bank is part of a holding company.
*/

gen id_rssd = bank_id
merge m:m id_rssd using xt_regulatory_top_holder.dta
gen bhc = cond(d_date > d_date_start_reg & d_date < d_date_end_reg,1,0)

ModernRankBasedRegressions 5 "size" " & bhc == 1"
ModernRankBasedRegressions 10 "size" " & bhc == 1"
ModernRankBasedRegressions 20 "size" " & bhc == 1"
ModernRankBasedRegressions 30 "size" " & bhc == 1"
ModernRankBasedRegressions 40 "size" " & bhc == 1"
ModernRankBasedRegressions 50 "size" " & bhc == 1"
ModernRankBasedRegressions 100 "size" " & bhc == 1"

ModernRankBasedRegressions 5 "cent" "" " & bhc == 1"
ModernRankBasedRegressions 10 "cent" "" " & bhc == 1"
ModernRankBasedRegressions 20 "cent" "" " & bhc == 1"
ModernRankBasedRegressions 30 "cent" "" " & bhc == 1"
ModernRankBasedRegressions 40 "cent" "" " & bhc == 1"
ModernRankBasedRegressions 50 "cent" "" " & bhc == 1"
ModernRankBasedRegressions 100 "cent" "" " & bhc == 1"

ModernRankBasedRegressions 5 "size" " & bhc == 0"
ModernRankBasedRegressions 10 "size" " & bhc == 0"
ModernRankBasedRegressions 20 "size" " & bhc == 0"
ModernRankBasedRegressions 30 "size" " & bhc == 0"
ModernRankBasedRegressions 40 "size" " & bhc == 0"
ModernRankBasedRegressions 50 "size" " & bhc == 0"

ModernRankBasedRegressions 5 "cent" "" " & bhc == 0"
ModernRankBasedRegressions 10 "cent" "" " & bhc == 0"
ModernRankBasedRegressions 20 "cent" "" " & bhc == 0"
ModernRankBasedRegressions 30 "cent" "" " & bhc == 0"
ModernRankBasedRegressions 40 "cent" "" " & bhc == 0"
ModernRankBasedRegressions 50 "cent" "" " & bhc == 0"

ModernRankBasedRegressions 5 "size" "" " & state_cd == 36"
ModernRankBasedRegressions 10 "size" "" " & state_cd == 36"
ModernRankBasedRegressions 20 "size" "" " & state_cd == 36"
ModernRankBasedRegressions 30 "size" "" " & state_cd == 36"
ModernRankBasedRegressions 40 "size" "" " & state_cd == 36"
ModernRankBasedRegressions 50 "size" "" " & state_cd == 36"

ModernRankBasedRegressions 5 "cent" "" " & state_cd == 36"
ModernRankBasedRegressions 10 "cent" "" " & state_cd == 36"
ModernRankBasedRegressions 20 "cent" "" " & state_cd == 36"
ModernRankBasedRegressions 30 "cent" "" " & state_cd == 36"
ModernRankBasedRegressions 40 "cent" "" " & state_cd == 36"
ModernRankBasedRegressions 50 "cent" "" " & state_cd == 36"

ModernRankBasedRegressions 5 "size" "" " & (state_cd == 36 | state_cd == 37 | state_cd == 10)"
ModernRankBasedRegressions 10 "size" "" " & (state_cd == 36 | state_cd == 37 | state_cd == 10)"
ModernRankBasedRegressions 20 "size" "" " & (state_cd == 36 | state_cd == 37 | state_cd == 10)"
ModernRankBasedRegressions 30 "size" "" " & (state_cd == 36 | state_cd == 37 | state_cd == 10)"
ModernRankBasedRegressions 40 "size" "" " & (state_cd == 36 | state_cd == 37 | state_cd == 10)"
ModernRankBasedRegressions 50 "size" "" " & (state_cd == 36 | state_cd == 37 | state_cd == 10)"

ModernRankBasedRegressions 5 "cent" "" " & (state_cd == 36 | state_cd == 37 | state_cd == 10)"
ModernRankBasedRegressions 10 "cent" "" " & (state_cd == 36 | state_cd == 37 | state_cd == 10)"
ModernRankBasedRegressions 20 "cent" "" " & (state_cd == 36 | state_cd == 37 | state_cd == 10)"
ModernRankBasedRegressions 30 "cent" "" " & (state_cd == 36 | state_cd == 37 | state_cd == 10)"
ModernRankBasedRegressions 40 "cent" "" " & (state_cd == 36 | state_cd == 37 | state_cd == 10)"
ModernRankBasedRegressions 50 "cent" "" " & (state_cd == 36 | state_cd == 37 | state_cd == 10)"


/*
based on https://www.mcc.co.mercer.pa.us/dps/state_fips_code_listing.htm
label define fips_states 1 "AL" 2 "AK" 4 "AZ" 5 "AR" 6 "CA" 8 "CO" 9 "CT" 10 "DE" 11 "DC" 12 "FL" 13 "GA" 15 "HI" 16 "ID" 17 "IL" 18 "IN" 19 "IA" 20 "KS" 21 "KY" 22 "LA" 23 "ME" 24 "MD" 25 "MA" 26 "MI" 27 "MN" 28 "MS" 29 "MO" 30 "MT" 31 "NE" 32 "NV" 33 "NH" 34 "NJ" 35 "NM" 36 "NY" 37 "NC" 38 "ND" 39 "OH" 40 "OK" 41 "OR" 42 "PA" 44 "RI" 45 "SC" 46 "SD" 47 "TN" 48 "TX" 49 "UT" 50 "VT" 51 "VA" 53 "WA" 54 "WV" 55 "WI" 56 "WY" 60 "AS" 66 "GU" 72 "PR" 78 "VI" 
*/


// REGRESSION DIFFERENTIATING BETWEEN SIZE CLASSES

capture noisily program drop ModernSizeCutoffRegressions
program define ModernSizeCutoffRegressions

	/*
	This file sorts the modern banks by assets in terms of a balance sheet size
	cutoff and compares capital dynamics with to the remaining banks.
	*/

	drop size_cat
	gen size_cat = 0
	replace size_cat = 1 if assets > `1'

	forvalue bc = 1/6 {

		global SubSet "tier1_leverage <50 & tier1_leverage>4 & IndDeNovo == 0"
		global controls "c_asset1 c_asset2 c_asset3"

		display "Business Cycle: `bc'"  
		display "Size Cutoff in $USbn: `1'"
		// no time-fixed effects
		xtreg tier1_leverage i.size_cat##c.m_bc_`bc' ${controls} if ${SubSet}, fe vce(cluster bank_id)
		display "`e(cmdline)'"
		lincom 1.size_cat#c.m_bc_`bc' - c.m_bc_`bc', cformat(%9.2fc) 
		results2xls `bc' 2
		di "`bc' `e(cmdline)' `e(depvar)' `r(estimate)' `r(se)' `1'"
		results2dta "`bc'" "`e(cmdline)'" "`e(depvar)'" "`r(estimate)'" "`r(se)'" "MOD `1'"

		display "Business Cycle: `bc'"  
		display "Size Cutoff in $USbn: `1'"
		// time-fixed effects 
		xtreg tier1_leverage i.size_cat##c.m_bc_`bc' i.q_date ${controls} if ${SubSet}, fe vce(cluster bank_id)
		display "`e(cmdline)'"
		lincom 1.size_cat#c.m_bc_`bc' - c.m_bc_`bc', cformat(%9.2fc) 
		lincom 1.size_cat#c.m_bc_`bc', cformat(%9.2fc) 
		results2xls `bc' 5
		di "`bc' `e(cmdline)' `e(depvar)' `r(estimate)' `r(se)' `1'"
		results2dta "`bc'" "`e(cmdline)'" "`e(depvar)'" "`r(estimate)'" "`r(se)'" "MOD `1' - TFE"

		global SubSet "tier1_risk_based <50 & tier1_risk_based>4 & IndDeNovo == 0"

		display "Business Cycle: `bc'"  
		display "Size Cutoff in $USbn: `1'"
		// no time-fixed effects
		xtreg tier1_risk_based i.size_cat##c.m_bc_`bc' ${controls} if ${SubSet}, fe vce(cluster bank_id)
		lincom 1.size_cat#c.m_bc_`bc' - c.m_bc_`bc', cformat(%9.2fc) 
		results2xls `bc' 8
		di "`bc' `e(cmdline)' `e(depvar)' `r(estimate)' `r(se)' `1'"
		results2dta "`bc'" "`e(cmdline)'" "`e(depvar)'" "`r(estimate)'" "`r(se)'" "MOD `1'"

		display "Business Cycle: `bc'"  
		display "Size Cutoff in $USbn: `1'"
		// time-fixed effects
		xtreg tier1_risk_based i.size_cat##c.m_bc_`bc' i.q_date ${controls} if ${SubSet}, fe vce(cluster bank_id)
		display "`e(cmdline)'"
		lincom 1.size_cat#c.m_bc_`bc' - c.m_bc_`bc', cformat(%9.2fc) 
		lincom 1.size_cat#c.m_bc_`bc', cformat(%9.2fc) 
		results2xls `bc' 11
		di "`bc' `e(cmdline)' `e(depvar)' `r(estimate)' `r(se)' `1'"
		results2dta "`bc'" "`e(cmdline)'" "`e(depvar)'" "`r(estimate)'" "`r(se)'" "MOD `1' - TFE"
		
		global SubSet "total_risk_based <50 & total_risk_based>4 & IndDeNovo == 0"

		display "Business Cycle: `bc'"  
		display "Size Cutoff in $USbn: `1'"
		// no time-fixed effects  
		xtreg total_risk_based i.size_cat##c.m_bc_`bc' ${controls} if ${SubSet}, fe vce(cluster bank_id)
		display "`e(cmdline)'"
		lincom 1.size_cat#c.m_bc_`bc' - c.m_bc_`bc', cformat(%9.2fc) 
		results2xls `bc' 14
		di "`bc' `e(cmdline)' `e(depvar)' `r(estimate)' `r(se)' `1'"
		results2dta "`bc'" "`e(cmdline)'" "`e(depvar)'" "`r(estimate)'" "`r(se)'" "MOD `1'"

		display "Business Cycle: `bc'"  
		display "Size Cutoff in $USbn: `1'"
		// time-fixed effects
		xtreg total_risk_based i.size_cat##c.m_bc_`bc' i.q_date ${controls} if ${SubSet}, fe vce(cluster bank_id)
		display "`e(cmdline)'"
		lincom 1.size_cat#c.m_bc_`bc' - c.m_bc_`bc', cformat(%9.2fc) 
		lincom 1.size_cat#c.m_bc_`bc', cformat(%9.2fc) 
		results2xls `bc' 17
		di "`bc' `e(cmdline)' `e(depvar)' `r(estimate)' `r(se)' `1'"
		results2dta "`bc'" "`e(cmdline)'" "`e(depvar)'" "`r(estimate)'" "`r(se)'" "MOD `1' - TFE"

		global SubSet "eqt < 50 & eqt > 4 & IndDeNovo == 0"

		display "Business Cycle: `bc'"  
		display "Size Cutoff in $USbn: `1'"
		// no time-fixed effects
		xtreg eqt i.size_cat##c.m_bc_`bc' ${controls} if ${SubSet}, fe vce(cluster bank_id)
		display "`e(cmdline)'"
		lincom 1.size_cat#c.m_bc_`bc' - c.m_bc_`bc', cformat(%9.2fc) 
		results2xls `bc' 20
		di "`bc' `e(cmdline)' `e(depvar)' `r(estimate)' `r(se)' `1'"
		results2dta "`bc'" "`e(cmdline)'" "`e(depvar)'" "`r(estimate)'" "`r(se)'" "MOD `1'"

		display "Business Cycle: `bc'"  
		display "Size Cutoff in $USbn: `1'"
		// time-fixed effects
		xtreg eqt i.size_cat##c.m_bc_`bc' i.q_date ${controls} if ${SubSet}, fe vce(cluster bank_id)
		display "`e(cmdline)'"
		lincom 1.size_cat#c.m_bc_`bc' - c.m_bc_`bc', cformat(%9.2fc) 
		lincom 1.size_cat#c.m_bc_`bc', cformat(%9.2fc) 
		results2xls `bc' 23   
		di "`bc' `e(cmdline)' `e(depvar)' `r(estimate)' `r(se)' `1'"
		results2dta "`bc'" "`e(cmdline)'" "`e(depvar)'" "`r(estimate)'" "`r(se)'" "MOD `1' - TFE"
      		
	}

	export excel ResultsColumnT ResultsColumn0 ResultsColumn1 ResultsColumn2 ResultsColumn3 ResultsColumn4 ResultsColumn5 ResultsColumn6 ///
	in 1/25 using "./output/tab_baseline.xlsx", sheet("mod SizeCut `2'") sheetreplace cell(b2) firstrow(varlabels) keepcellfmt

end 


ModernSizeCutoffRegressions 250000000 "250bn"
ModernSizeCutoffRegressions 100000000 "100bn"
ModernSizeCutoffRegressions 50000000 "50bn"
ModernSizeCutoffRegressions 10000000 "10bn"

savesome dtaID dtaBusCy dtaModel dtaDepVar dtaSizeCutoff dtaEstimate dtaStdErr using xt_visualization2.dta, replace
		
capture noisily log close modern
		
// END OF FILE //
