/*
filename: tab_5_risk_weighting_historical.do

This file runs all historical cleaning files, the file that generates 
historical and modern unit intervals, and the file that combines all 
historical data sets.

The file then estimates unit interval time trend regressions with 
various risk weights for the assets of the historical banks.

The file contains the following programs:

- NewHistoricalReportingTemplate
- results2xls
- results2dta
*/

clear
// running file that combines all four historical data sets
do ./code/dtm_combine_historical_banks.do

tab d_date
tab source if d_date==.

merge m:1 d_date using ./data/ts_business_cycles_on_unit_interval.dta

tab _merge

keep if _merge ==3
drop _merge
drop m_bc_*
drop if bank_id == .

replace year = year(d_date)
drop age*
gen age = year - organized
order cent_rank_in_call_id size_rank_in_call_id source call_id age 

/*
We generate a flag to remove those national bank observations that are in both nat_qa and nat_qq.
*/

gen flag=0
replace flag = 1 if source == "nat_qa" & dbl_id>9000 &  (call_id == 3 | call_id == 7 | call_id == 11 | call_id == 15 | call_id == 19 | call_id == 23 | call_id == 26 | call_id == 31 | call_id == 35)

drop if flag==1
// Removing the annual national bank observations that are also in the quarterly national bank data set.



duplicates list bank_id call_id
duplicates list bank_id name call_id



drop if name == "BLANK"
drop if name == "NATIONAL BANK OF BAY RIDGE, BROOKLYN"
drop if name == "GLENS FALLS, FIRST"

xtset bank_id call_id

// more on the lincom constraints: https://www.stata.com/statalist/archive/2012-11/msg01179.html

program drop _all
program define NewHistoricalReportingTemplate



	capture noisily drop Results*
	gen ResultsColumnT = "" in 1
	replace ResultsColumnT = "Top 10" in 2
	replace ResultsColumnT = "Size" in 3
	replace ResultsColumnT = "Top 10" in 8
	replace ResultsColumnT = "Central" in 9
	replace ResultsColumnT = "Top 10" in 14
	replace ResultsColumnT = "Foreign" in 15

	gen ResultsColumn0 = "Specification" in 1
	replace ResultsColumn0 = "Baseline" in 2
	replace ResultsColumn0 = "S.E." in 3
	replace ResultsColumn0 = "Time-Fixed Effects" in 5
	replace ResultsColumn0 = "S.E." in 6

	replace ResultsColumn0 = "Baseline" in 8
	replace ResultsColumn0 = "S.E." in 9
	replace ResultsColumn0 = "Time-Fixed Effects" in 11
	replace ResultsColumn0 = "S.E." in 12

	replace ResultsColumn0 = "Baseline" in 14
	replace ResultsColumn0 = "S.E." in 15
	replace ResultsColumn0 = "Time-Fixed Effects" in 17
	replace ResultsColumn0 = "S.E." in 18

	gen ResultsColumn1 = "Business Cycle Definition 1" in 1
	gen ResultsColumn2 = "Business Cycle Definition 2" in 1
	gen ResultsColumn3 = "Business Cycle Definition 3" in 1
	gen ResultsColumn4 = "Business Cycle Definition 4" in 1
	gen ResultsColumn5 = "Business Cycle Definition 5" in 1
	gen ResultsColumn6 = "Business Cycle Definition 6" in 1

	label var ResultsColumn1 "NBER"
	label var ResultsColumn2 "Short-term interest rate"
	label var ResultsColumn3 "Consumption"
	label var ResultsColumn4 "DJIA"
	label var ResultsColumn5 "Volume of Payments"
	label var ResultsColumn6 "Total Payroll"

	order ResultsColumnT Results*, first
	
end

program define results2xls
	/*
	This program puts the results with appropriate significance "stars" 
	into a simple exportable format.

	syntax -- results2xls c1 r1 -- where c1 is the column and r1 the row numnber
	standar errors are automatically added one row underneath in parenthesis.
	*/

	local counter1 = `2'
	local counter2 = `counter1' + 1

	local aux1: di %9.2fc `r(estimate)' 
	if `r(p)' <=0.01 {
		replace ResultsColumn`1' = "`aux1'***" in `counter1'
	}
	else if `r(p)' <=0.05 {
		replace ResultsColumn`1' = "`aux1'**" in `counter1'
	}
	else if `r(p)' <=0.1 {
		replace ResultsColumn`1' = "`aux1'*" in `counter1'
	}
	else if `r(p)' > 0.1 {
		replace ResultsColumn`1' = "`aux1'" in `counter1'
	}
	local aux2: di %9.2fc `r(se)'
	replace ResultsColumn`1' = "(`aux2')" in `counter2'
	replace ResultsColumn`1' = subinstr(ResultsColumn`1'," ","",.) in 2/l
	
end 

// generating six results summaries for the subsequent results visualization  
gen dtaID = .
gen dtaBusCy = .
gen dtaModel = ""
gen dtaDepVar = ""
gen dtaEstimate = . 
gen dtaStdErr = .

global RegNoCounter = 0
program define results2dta
	
	/*
	The correct execution of this program and the counter 
	requires a sequential running of:
	
	1. tab_1_baseline_regressions.do
	2. tab_2_robustness_regressions.do
	3. tab_3_modern_regression.do
	
	via -- do tab_1_baseline_regressions.do -- (1 calls 2 and 3)
	*/
	
	global RegNoCounter = ${RegNoCounter} + 1
	replace dtaID = ${RegNoCounter} in ${RegNoCounter}
	replace dtaBusCy = `1' in ${RegNoCounter}
	replace dtaModel = `'"`2'"' in ${RegNoCounter}
	replace dtaDepVar = "`3'" in ${RegNoCounter}
	replace dtaEstimate = `4' in ${RegNoCounter}
	replace dtaStdErr = `5' in ${RegNoCounter}
end

// ASSET PORTFOLIO DECOMPOSITION
gen c_assets1 = 100*(a_tot_loans/assets)
gen c_assets2 = 100*(a_tot_inv/assets)
gen c_assets3 = 100*(a_tot_cash/assets)
gen c_assets4 = 100*(a_tot_other/assets)

summ c_assets1, d
summ c_assets2, d
summ c_assets3, d
summ c_assets4, d

// GENERATING RISK_WEIGHTED ASSETS
gen rw_assets = 0.75*a_tot_loans +0.0*a_tot_cash + 0.50*a_tot_inv + a_tot_other
gen rw_eqt = 100*equity/rw_assets

capture noisily log close _all
capture noisily log using ./output/log_1_baseline_regressions.log, text name(baseline) replace

global SubSet "age>5 & eqt <50"
global controls "c_assets1 c_assets2 c_assets3 "

// clearing the reporting template and replacing it with a blank one
// to prevent "carry over" from stale (previous) estimates
NewHistoricalReportingTemplate

forvalues bc = 1/6 {
	
	// TOP 10 SIZED BANKS //
	di "Business Cycle: `bc'"
	// no time-fixed effects
	xtreg rw_eqt i.top10_size1929##c.h_bc_`bc' ${controls} if ${SubSet}, fe vce(cluster bank_id)
	display "`e(cmdline)'"
	lincom 1.top10_size1929#c.h_bc_`bc' - c.h_bc_`bc', cformat(%9.2fc) 
	results2xls `bc' 2
    di "`bc' `e(cmdline)' `e(depvar)' `r(estimate)' `r(se)'"
	results2dta "`bc'" "`e(cmdline)'" "`e(depvar)'" "`r(estimate)'" "`r(se)'"

	di "Business Cycle: `bc'"
	// time-fixed effects 
	xtreg rw_eqt i.top10_size1929##c.h_bc_`bc' i.call_id ${controls} if ${SubSet}, fe vce(cluster bank_id)
	display "`e(cmdline)'"
	lincom 1.top10_size1929#c.h_bc_`bc' - c.h_bc_`bc', cformat(%9.2fc)  
	lincom 1.top10_size1929#c.h_bc_`bc', cformat(%9.2fc)  
	results2xls `bc' 5
    di "`bc' `e(cmdline)' `e(depvar)' `r(estimate)' `r(se)'"
	results2dta "`bc'" "`e(cmdline)'" "`e(depvar)'" "`r(estimate)'" "`r(se)'"

	// TOP 10 "CENTRAL" BANKS //
	di "Business Cycle: `bc'"
	// no time-fixed effects
	xtreg rw_eqt i.top10_cent1929##c.h_bc_`bc' ${controls} if ${SubSet}, fe vce(cluster bank_id)
	display "`e(cmdline)'"
	lincom 1.top10_cent1929#c.h_bc_`bc' - c.h_bc_`bc', cformat(%9.2fc) 
	results2xls `bc' 8
    di "`bc' `e(cmdline)' `e(depvar)' `r(estimate)' `r(se)'"
	results2dta "`bc'" "`e(cmdline)'" "`e(depvar)'" "`r(estimate)'" "`r(se)'"

	di "Business Cycle: `bc'"
	// time-fixed effects
	xtreg rw_eqt i.top10_cent1929##c.h_bc_`bc' i.call_id ${controls} if ${SubSet}, fe vce(cluster bank_id)
	display "`e(cmdline)'"
	lincom 1.top10_cent1929#c.h_bc_`bc' - c.h_bc_`bc', cformat(%9.2fc)  
	lincom 1.top10_cent1929#c.h_bc_`bc', cformat(%9.2fc)  
	results2xls `bc' 11
    di "`bc' `e(cmdline)' `e(depvar)' `r(estimate)' `r(se)'"
	results2dta "`bc'" "`e(cmdline)'" "`e(depvar)'" "`r(estimate)'" "`r(se)'"

	// TOP 10 FOREIGN BANKS //
	di "Business Cycle: `bc'"
	// no time-fixed effects
	xtreg rw_eqt i.top10_frgn1929##c.h_bc_`bc' ${controls} if ${SubSet}, fe vce(cluster bank_id)
	display "`e(cmdline)'"
	lincom 1.top10_frgn1929#c.h_bc_`bc' - c.h_bc_`bc', cformat(%9.2fc) 
	results2xls `bc' 14
    di "`bc' `e(cmdline)' `e(depvar)' `r(estimate)' `r(se)'"
	results2dta "`bc'" "`e(cmdline)'" "`e(depvar)'" "`r(estimate)'" "`r(se)'"

	di "Business Cycle: `bc'"
	// time-fixed effects
	xtreg rw_eqt i.top10_frgn1929##c.h_bc_`bc' i.call_id ${controls} if ${SubSet}, fe vce(cluster bank_id)
	display "`e(cmdline)'"
	lincom 1.top10_frgn1929#c.h_bc_`bc' - c.h_bc_`bc', cformat(%9.2fc)  
	lincom 1.top10_frgn1929#c.h_bc_`bc', cformat(%9.2fc)  
	results2xls `bc' 17
    di "`bc' `e(cmdline)' `e(depvar)' `r(estimate)' `r(se)'"
	results2dta "`bc'" "`e(cmdline)'" "`e(depvar)'" "`r(estimate)'" "`r(se)'"

}

export excel ResultsColumnT ResultsColumn0 ResultsColumn1 ResultsColumn2 ResultsColumn3 ResultsColumn4 ResultsColumn5 ResultsColumn6 ///
in 1/20 using "./output/tab_baseline.xlsx", sheet("baseline") sheetreplace cell(b2) firstrow(varlabels) keepcellfmt


// clearing the reporting template and replacing it with a blank one
// to prevent "carry over" from stale (previous) estimates
NewHistoricalReportingTemplate

forvalues bc = 1/6 {

	// TOP 10 SIZED BANKS //
	di "Business Cycle: `bc'"
	// no time-fixed effects
	xtreg rw_eqt i.top10_size1929##c.h_bc_`bc' ${controls} if ${SubSet}, fe 
	display "`e(cmdline)'"
	lincom 1.top10_size1929#c.h_bc_`bc' - c.h_bc_`bc', cformat(%9.2fc) 
	results2xls `bc' 2
    di "`bc' `e(cmdline)' `e(depvar)' `r(estimate)' `r(se)'"
	results2dta "`bc'" "`e(cmdline)'" "`e(depvar)'" "`r(estimate)'" "`r(se)'"


	di "Business Cycle: `bc'"
	// time-fixed effects
	xtreg rw_eqt i.top10_size1929##c.h_bc_`bc' i.call_id ${controls} if ${SubSet}, fe 
	display "`e(cmdline)'"	
	lincom 1.top10_size1929#c.h_bc_`bc' - c.h_bc_`bc', cformat(%9.2fc)  
	lincom 1.top10_size1929#c.h_bc_`bc', cformat(%9.2fc)  
	results2xls `bc' 5
    di "`bc' `e(cmdline)' `e(depvar)' `r(estimate)' `r(se)'"
	results2dta "`bc'" "`e(cmdline)'" "`e(depvar)'" "`r(estimate)'" "`r(se)'"

	// TOP 10 "CENTRAL" BANKS //
	di "Business Cycle: `bc'"
	// no time-fixed effects
	xtreg rw_eqt i.top10_cent1929##c.h_bc_`bc' ${controls} if ${SubSet}, fe 
	display "`e(cmdline)'"	
	lincom 1.top10_cent1929#c.h_bc_`bc' - c.h_bc_`bc', cformat(%9.2fc) 
	results2xls `bc' 8
    di "`bc' `e(cmdline)' `e(depvar)' `r(estimate)' `r(se)'"
	results2dta "`bc'" "`e(cmdline)'" "`e(depvar)'" "`r(estimate)'" "`r(se)'"

	di "Business Cycle: `bc'"
	// time-fixed effects
	xtreg rw_eqt i.top10_cent1929##c.h_bc_`bc' i.call_id ${controls} if ${SubSet}, fe 
	display "`e(cmdline)'"
	lincom 1.top10_cent1929#c.h_bc_`bc' - c.h_bc_`bc', cformat(%9.2fc)  
	lincom 1.top10_cent1929#c.h_bc_`bc', cformat(%9.2fc)  
	results2xls `bc' 11
    di "`bc' `e(cmdline)' `e(depvar)' `r(estimate)' `r(se)'"
	results2dta "`bc'" "`e(cmdline)'" "`e(depvar)'" "`r(estimate)'" "`r(se)'"

	// TOP 10 FOREIGN BANKS //
	di "Business Cycle: `bc'"
	// no time-fixed effects
	xtreg rw_eqt i.top10_frgn1929##c.h_bc_`bc' ${controls} if ${SubSet}, fe 
	display "`e(cmdline)'"	
	lincom 1.top10_frgn1929#c.h_bc_`bc' - c.h_bc_`bc', cformat(%9.2fc) 
	results2xls `bc' 14
    di "`bc' `e(cmdline)' `e(depvar)' `r(estimate)' `r(se)'"
	results2dta "`bc'" "`e(cmdline)'" "`e(depvar)'" "`r(estimate)'" "`r(se)'"

	di "Business Cycle: `bc'"
	// time-fixed effects
	xtreg rw_eqt i.top10_frgn1929##c.h_bc_`bc' i.call_id ${controls} if ${SubSet}, fe 
	display "`e(cmdline)'"	
	lincom 1.top10_frgn1929#c.h_bc_`bc' - c.h_bc_`bc', cformat(%9.2fc)  
	lincom 1.top10_frgn1929#c.h_bc_`bc', cformat(%9.2fc)  
	results2xls `bc' 17
    di "`bc' `e(cmdline)' `e(depvar)' `r(estimate)' `r(se)'"
	results2dta "`bc'" "`e(cmdline)'" "`e(depvar)'" "`r(estimate)'" "`r(se)'"
}

export excel ResultsColumnT ResultsColumn0 ResultsColumn1 ResultsColumn2 ResultsColumn3 ResultsColumn4 ResultsColumn5 ResultsColumn6 ///
in 1/20 using "./output/tab_baseline.xlsx", sheet("no robust") sheetreplace cell(b2) firstrow(varlabels) keepcellfmt

// clearing the reporting template and replacing it with a blank one
// to prevent "carry over" from stale (previous) estimates
NewHistoricalReportingTemplate

// TOP 10 SIZED BANKS //
// no time-fixed effects
forvalues bc = 1/6 {

	// TOP 10 SIZED BANKS //
	di "Business Cycle: `bc'"
	// no time-fixed effects
	reg rw_eqt i.top10_size1929##c.h_bc_`bc' ${controls} if ${SubSet} 
	display "`e(cmdline)'"
	lincom 1.top10_size1929#c.h_bc_`bc' - c.h_bc_`bc', cformat(%9.2fc) 
	results2xls `bc' 2
    di "`bc' `e(cmdline)' `e(depvar)' `r(estimate)' `r(se)'"
	results2dta "`bc'" "`e(cmdline)'" "`e(depvar)'" "`r(estimate)'" "`r(se)'"

	di "Business Cycle: `bc'"
	// time-fixed effects	
	reg rw_eqt i.top10_size1929##c.h_bc_`bc' i.call_id ${controls} if ${SubSet} 
	display "`e(cmdline)'"
	lincom 1.top10_size1929#c.h_bc_`bc' - c.h_bc_`bc', cformat(%9.2fc)  
	lincom 1.top10_size1929#c.h_bc_`bc', cformat(%9.2fc)  
	results2xls `bc' 5
    di "`bc' `e(cmdline)' `e(depvar)' `r(estimate)' `r(se)'"
	results2dta "`bc'" "`e(cmdline)'" "`e(depvar)'" "`r(estimate)'" "`r(se)'"

	// TOP 10 "CENTRAL" BANKS //
	di "Business Cycle: `bc'"
	// no time-fixed effects
	reg rw_eqt i.top10_cent1929##c.h_bc_`bc' ${controls} if ${SubSet} 
	display "`e(cmdline)'"	
	lincom 1.top10_cent1929#c.h_bc_`bc' - c.h_bc_`bc', cformat(%9.2fc) 
	results2xls `bc' 8
    di "`bc' `e(cmdline)' `e(depvar)' `r(estimate)' `r(se)'"
	results2dta "`bc'" "`e(cmdline)'" "`e(depvar)'" "`r(estimate)'" "`r(se)'"

	di "Business Cycle: `bc'"
	// time-fixed effects
	reg rw_eqt i.top10_cent1929##c.h_bc_`bc' i.call_id ${controls} if ${SubSet} 
	display "`e(cmdline)'"
	lincom 1.top10_cent1929#c.h_bc_`bc' - c.h_bc_`bc', cformat(%9.2fc)  
	lincom 1.top10_cent1929#c.h_bc_`bc', cformat(%9.2fc)  
	results2xls `bc' 11
    di "`bc' `e(cmdline)' `e(depvar)' `r(estimate)' `r(se)'"
	results2dta "`bc'" "`e(cmdline)'" "`e(depvar)'" "`r(estimate)'" "`r(se)'"

	// TOP 10 FOREIGN BANKS //
	di "Business Cycle: `bc'"
	// no time-fixed effects
	reg rw_eqt i.top10_frgn1929##c.h_bc_`bc' ${controls} if ${SubSet} 

	lincom 1.top10_frgn1929#c.h_bc_`bc' - c.h_bc_`bc', cformat(%9.2fc) 
	results2xls `bc' 14
    di "`bc' `e(cmdline)' `e(depvar)' `r(estimate)' `r(se)'"
	results2dta "`bc'" "`e(cmdline)'" "`e(depvar)'" "`r(estimate)'" "`r(se)'"
	
	di "Business Cycle: `bc'"
	// time-fixed effects
	reg rw_eqt i.top10_frgn1929##c.h_bc_`bc' i.call_id ${controls} if ${SubSet} 
	display "`e(cmdline)'"
	lincom 1.top10_frgn1929#c.h_bc_`bc' - c.h_bc_`bc', cformat(%9.2fc)  
	lincom 1.top10_frgn1929#c.h_bc_`bc', cformat(%9.2fc)  
	results2xls `bc' 17
    di "`bc' `e(cmdline)' `e(depvar)' `r(estimate)' `r(se)'"
	results2dta "`bc'" "`e(cmdline)'" "`e(depvar)'" "`r(estimate)'" "`r(se)'"
}

export excel ResultsColumnT ResultsColumn0 ResultsColumn1 ResultsColumn2 ResultsColumn3 ResultsColumn4 ResultsColumn5 ResultsColumn6 ///
in 1/20 using "./output/tab_baseline.xlsx", sheet("no FE") sheetreplace cell(b2) firstrow(varlabels) keepcellfmt

capture noisily log close baseline

do ./code/tab_2_robustness_regressions.do
do ./code/tab_3_modern_regressions.do

// END OF FILE //
